@@ -1,6 +1,15 @@
-__version__ = "1.7"
+__version__ = "1.13"
 
-from . import api, ops  # noqa
+import warnings
+
+
+with warnings.catch_warnings():
+    warnings.filterwarnings(
+        "ignore",
+        message="distutils Version classes are deprecated. Use packaging.version instead.",
+    )
+    from . import api, ops  # noqa
+    from .logging import logger  # noqa
 
 
 if __name__ == "__main__":
